@@ -2,7 +2,8 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * @todo    too much die here, or?
- * @version $Id: export.php 11450 2008-08-01 19:15:01Z lem9 $
+ * @version $Id$
+ * @package phpMyAdmin
  */
 
 /**
@@ -58,9 +59,8 @@ if (empty($_REQUEST['asfile'])) {
 
 // Does export require to be into file?
 if (isset($export_list[$type]['force_file']) && ! $asfile) {
-    $message = $strExportMustBeFile;
-    $GLOBALS['show_error_header'] = true;
-    $js_to_run = 'functions.js';
+    $message = PMA_Message::error('strExportMustBeFile');
+    $GLOBALS['js_include'][] = 'functions.js';
     require_once './libraries/header.inc.php';
     if ($export_type == 'server') {
         $active_page = 'server_export.php';
@@ -151,8 +151,8 @@ function PMA_exportOutputHandler($line)
                 if ($GLOBALS['save_on_server']) {
                     $write_result = @fwrite($GLOBALS['file_handle'], $dump_buffer);
                     if (!$write_result || ($write_result != strlen($dump_buffer))) {
-                        $GLOBALS['message'] = sprintf($GLOBALS['strNoSpace'], htmlspecialchars($save_filename));
-                        $GLOBALS['show_error_header'] = true;
+                        $GLOBALS['message'] = PMA_Message::error('strNoSpace');
+                        $GLOBALS['message']->addParam($save_filename);
                         return false;
                     }
                 } else {
@@ -176,8 +176,8 @@ function PMA_exportOutputHandler($line)
             if ($GLOBALS['save_on_server'] && strlen($line) > 0) {
                 $write_result = @fwrite($GLOBALS['file_handle'], $line);
                 if (!$write_result || ($write_result != strlen($line))) {
-                    $GLOBALS['message'] = sprintf($GLOBALS['strNoSpace'], htmlspecialchars($save_filename));
-                    $GLOBALS['show_error_header'] = true;
+                    $GLOBALS['message'] = PMA_Message::error('strNoSpace');
+                    $GLOBALS['message']->addParam($save_filename);
                     return false;
                 }
                 $time_now = time();
@@ -207,13 +207,12 @@ if ($what == 'sql') {
 $output_kanji_conversion = function_exists('PMA_kanji_str_conv') && $type != 'xls';
 
 // Do we need to convert charset?
-$output_charset_conversion = $asfile &&
-    $cfg['AllowAnywhereRecoding'] && $allow_recoding
+$output_charset_conversion = $asfile && $cfg['AllowAnywhereRecoding']
     && isset($charset_of_file) && $charset_of_file != $charset
     && $type != 'xls';
 
-// Use on fly compression?
-$onfly_compression = $GLOBALS['cfg']['CompressOnFly'] && ($compression == 'gzip' | $compression == 'bzip');
+// Use on the fly compression?
+$onfly_compression = $GLOBALS['cfg']['CompressOnFly'] && ($compression == 'gzip' || $compression == 'bzip');
 if ($onfly_compression) {
     $memory_limit = trim(@ini_get('memory_limit'));
     // 2 MB as default
@@ -263,7 +262,7 @@ if ($asfile) {
     }
 
     // convert filename to iso-8859-1, it is safer
-    if (!(isset($cfg['AllowAnywhereRecoding']) && $cfg['AllowAnywhereRecoding'] && $allow_recoding)) {
+    if (!(isset($cfg['AllowAnywhereRecoding']) && $cfg['AllowAnywhereRecoding'] )) {
         $filename = PMA_convert_string($charset, 'iso-8859-1', $filename);
     } else {
         $filename = PMA_convert_string($convcharset, 'iso-8859-1', $filename);
@@ -273,27 +272,14 @@ if ($asfile) {
     $filename  .= '.' . $export_list[$type]['extension'];
     $mime_type  = $export_list[$type]['mime_type'];
 
-    // If dump is going to be compressed, set correct encoding or mime_type and add
+    // If dump is going to be compressed, set correct mime_type and add
     // compression to extension
-    $content_encoding = '';
     if ($compression == 'bzip') {
         $filename  .= '.bz2';
-        // browsers don't like this:
-        //$content_encoding = 'x-bzip2';
         $mime_type = 'application/x-bzip2';
     } elseif ($compression == 'gzip') {
         $filename  .= '.gz';
-        // Needed to avoid recompression by server modules like mod_gzip.
-        // It seems necessary to check about zlib.output_compression
-        // to avoid compressing twice
-        if (!@ini_get('zlib.output_compression')) {
-            // On Firefox 3, sending this content encoding corrupts the .gz
-            // (as tested on Windows and Linux) but detect GECKO 1.9
-            if (! (PMA_USR_BROWSER_AGENT == 'GECKO' && PMA_USR_BROWSER_VER == '1.9')) {
-                $content_encoding = 'x-gzip';
-            }
-            $mime_type = 'application/x-gzip';
-        }
+        $mime_type = 'application/x-gzip';
     } elseif ($compression == 'zip') {
         $filename  .= '.zip';
         $mime_type = 'application/zip';
@@ -305,21 +291,21 @@ if ($save_on_server) {
     $save_filename = PMA_userDir($cfg['SaveDir']) . preg_replace('@[/\\\\]@', '_', $filename);
     unset($message);
     if (file_exists($save_filename) && empty($onserverover)) {
-        $message = sprintf($strFileAlreadyExists, htmlspecialchars($save_filename));
-        $GLOBALS['show_error_header'] = true;
+        $message = PMA_Message::error('strFileAlreadyExists');
+        $message->addParam($save_filename);
     } else {
         if (is_file($save_filename) && !is_writable($save_filename)) {
-            $message = sprintf($strNoPermission, htmlspecialchars($save_filename));
-            $GLOBALS['show_error_header'] = true;
+            $message = PMA_Message::error('strNoPermission');
+            $message->addParam($save_filename);
         } else {
             if (!$file_handle = @fopen($save_filename, 'w')) {
-                $message = sprintf($strNoPermission, htmlspecialchars($save_filename));
-                $GLOBALS['show_error_header'] = true;
+                $message = PMA_Message::error('strNoPermission');
+                $message->addParam($save_filename);
             }
         }
     }
     if (isset($message)) {
-        $js_to_run = 'functions.js';
+        $GLOBALS['js_include'][] = 'functions.js';
         require_once './libraries/header.inc.php';
         if ($export_type == 'server') {
             $active_page = 'server_export.php';
@@ -346,9 +332,6 @@ if (!$save_on_server) {
         // this was reported to happen under Plesk)
         @ini_set('url_rewriter.tags','');
 
-        if (!empty($content_encoding)) {
-            header('Content-Encoding: ' . $content_encoding);
-        }
         header('Content-Type: ' . $mime_type);
         header('Expires: ' . gmdate('D, d M Y H:i:s') . ' GMT');
         // lem9: Tested behavior of
@@ -364,18 +347,17 @@ if (!$save_on_server) {
         } else {
             header('Pragma: no-cache');
             // test case: exporting a database into a .gz file with Safari
-            // would produce files not having the current time 
-            if ('SAFARI' == PMA_USR_BROWSER_AGENT) {
-                header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
-            } 
+            // would produce files not having the current time
+            // (added this header for Safari but should not harm other browsers)
+            header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
         }
     } else {
         // HTML
         if ($export_type == 'database') {
             $num_tables = count($tables);
             if ($num_tables == 0) {
-                $message = $strNoTablesFound;
-                $js_to_run = 'functions.js';
+                $message = PMA_Message::error('strNoTablesFound');
+                $GLOBALS['js_include'][] = 'functions.js';
                 require_once './libraries/header.inc.php';
                 $active_page = 'db_export.php';
                 require './db_export.php';
@@ -431,7 +413,7 @@ if ($export_type == 'server') {
         $tmp_select = '|' . $tmp_select . '|';
     }
     // Walk over databases
-    foreach ($GLOBALS['PMA_List_Database']->items as $current_db) {
+    foreach ($GLOBALS['pma']->databases as $current_db) {
         if ((isset($tmp_select) && strpos(' ' . $tmp_select, '|' . $current_db . '|'))
             || !isset($tmp_select)) {
             if (!PMA_exportDBHeader($current_db)) {
@@ -456,12 +438,20 @@ if ($export_type == 'server') {
                         break 3;
                     }
                 }
-                if (isset($GLOBALS[$what . '_data']) && ! $is_view) {
+                // if this is a view or a merge table, don't export data
+                if (isset($GLOBALS[$what . '_data']) && !($is_view || PMA_Table::isMerge($current_db, $table))) {
                     $local_query  = 'SELECT * FROM ' . PMA_backquote($current_db) . '.' . PMA_backquote($table);
                     if (!PMA_exportData($current_db, $table, $crlf, $err_url, $local_query)) {
                         break 3;
                     }
                 }
+                // now export the triggers (needs to be done after the data because
+                // triggers can modify already imported tables)
+                if (isset($GLOBALS[$what . '_structure'])) {
+                    if (!PMA_exportStructure($current_db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'triggers', $export_type)) {
+                        break 2;
+                    }
+                }
             }
             foreach($views as $view) {
                 // no data export for a view
@@ -497,12 +487,20 @@ if ($export_type == 'server') {
                 break 2;
             }
         }
-        if (isset($GLOBALS[$what . '_data']) && ! $is_view) {
+        // if this is a view or a merge table, don't export data
+        if (isset($GLOBALS[$what . '_data']) && !($is_view || PMA_Table::isMerge($db, $table))) {
             $local_query  = 'SELECT * FROM ' . PMA_backquote($db) . '.' . PMA_backquote($table);
             if (!PMA_exportData($db, $table, $crlf, $err_url, $local_query)) {
                 break 2;
             }
         }
+        // now export the triggers (needs to be done after the data because
+        // triggers can modify already imported tables)
+        if (isset($GLOBALS[$what . '_structure'])) {
+            if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'triggers', $export_type)) {
+                break 2;
+            }
+        }
     }
     foreach ($views as $view) {
         // no data export for a view
@@ -521,8 +519,8 @@ if ($export_type == 'server') {
         break;
     }
     // We export just one table
-
-    if ($limit_to > 0 && $limit_from >= 0) {
+    // $allrows comes from the form when "Dump all rows" has been selected
+    if ($allrows == '0' && $limit_to > 0 && $limit_from >= 0) {
         $add_query  = ' LIMIT '
                     . (($limit_from > 0) ? $limit_from . ', ' : '')
                     . $limit_to;
@@ -538,7 +536,8 @@ if ($export_type == 'server') {
     }
     // If this is an export of a single view, we have to export data;
     // for example, a PDF report
-    if (isset($GLOBALS[$what . '_data'])) {
+    // if it is a merge table, no data is exported
+    if (isset($GLOBALS[$what . '_data']) && ! PMA_Table::isMerge($db, $table)) {
         if (!empty($sql_query)) {
             // only preg_replace if needed
             if (!empty($add_query)) {
@@ -554,6 +553,13 @@ if ($export_type == 'server') {
             break;
         }
     }
+    // now export the triggers (needs to be done after the data because
+    // triggers can modify already imported tables)
+    if (isset($GLOBALS[$what . '_structure'])) {
+        if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'triggers', $export_type)) {
+            break 2;
+        }
+    }
     if (!PMA_exportDBFooter($db)) {
         break;
     }
@@ -566,7 +572,7 @@ if (!PMA_exportFooter()) {
 // End of fake loop
 
 if ($save_on_server && isset($message)) {
-    $js_to_run = 'functions.js';
+    $GLOBALS['js_include'][] = 'functions.js';
     require_once './libraries/header.inc.php';
     if ($export_type == 'server') {
         $active_page = 'server_export.php';
@@ -603,16 +609,11 @@ if (!empty($asfile)) {
     elseif ($compression == 'bzip') {
         if (@function_exists('bzcompress')) {
             $dump_buffer = bzcompress($dump_buffer);
-            if ($dump_buffer === -8) {
-                require_once './libraries/header.inc.php';
-                echo sprintf($strBzError, '<a href="http://bugs.php.net/bug.php?id=17300" target="_blank">17300</a>');
-                require_once './libraries/footer.inc.php';
-            }
         }
     }
     // 3. as a gzipped file
     elseif ($compression == 'gzip') {
-        if (@function_exists('gzencode')) {
+        if (@function_exists('gzencode') && !@ini_get('zlib.output_compression')) {
             // without the optional parameter level because it bug
             $dump_buffer = gzencode($dump_buffer);
         }
@@ -623,12 +624,12 @@ if (!empty($asfile)) {
         $write_result = @fwrite($file_handle, $dump_buffer);
         fclose($file_handle);
         if (strlen($dump_buffer) !=0 && (!$write_result || ($write_result != strlen($dump_buffer)))) {
-            $message = sprintf($strNoSpace, htmlspecialchars($save_filename));
+            $message = new PMA_Message('strNoSpace', PMA_Message::ERROR, $save_filename);
         } else {
-            $message = sprintf($strDumpSaved, htmlspecialchars($save_filename));
+            $message = new PMA_Message('strDumpSaved', PMA_Message::SUCCESS, $save_filename);
         }
 
-        $js_to_run = 'functions.js';
+        $GLOBALS['js_include'][] = 'functions.js';
         require_once './libraries/header.inc.php';
         if ($export_type == 'server') {
             $active_page = 'server_export.php';
