@@ -2,7 +2,7 @@
 /**
  * general function, usally for data manipulation pages
  *
- * @version $Id: functions.js 12919 2009-09-04 16:39:03Z lem9 $
+ * @version $Id$
  */
 
 /**
@@ -152,7 +152,7 @@ function confirmQuery(theForm1, sqlQuery1)
             } // end if
         } // end if
 
-        // Confirms a "DROP/DELETE/ALTER" statement
+        // Confirms a "DROP/DELETE/ALTER/TRUNCATE" statement
         //
         // TODO: find a way (if possible) to use the parser-analyser
         // for this kind of verification
@@ -162,22 +162,24 @@ function confirmQuery(theForm1, sqlQuery1)
         var do_confirm_re_0 = new RegExp('^\\s*DROP\\s+(IF EXISTS\\s+)?(TABLE|DATABASE|PROCEDURE)\\s', 'i');
         var do_confirm_re_1 = new RegExp('^\\s*ALTER\\s+TABLE\\s+((`[^`]+`)|([A-Za-z0-9_$]+))\\s+DROP\\s', 'i');
         var do_confirm_re_2 = new RegExp('^\\s*DELETE\\s+FROM\\s', 'i');
+        var do_confirm_re_3 = new RegExp('^\\s*TRUNCATE\\s', 'i');
+
         if (do_confirm_re_0.test(sqlQuery1.value)
             || do_confirm_re_1.test(sqlQuery1.value)
-            || do_confirm_re_2.test(sqlQuery1.value)) {
+            || do_confirm_re_2.test(sqlQuery1.value)
+            || do_confirm_re_3.test(sqlQuery1.value)) {
             var message      = (sqlQuery1.value.length > 100)
                              ? sqlQuery1.value.substr(0, 100) + '\n    ...'
                              : sqlQuery1.value;
             var is_confirmed = confirm(PMA_messages['strDoYouReally'] + ' :\n' + message);
-            // drop/delete/alter statement is confirmed -> update the
+            // statement is confirmed -> update the
             // "is_js_confirmed" form field so the confirm test won't be
             // run on the server side and allows to submit the form
             if (is_confirmed) {
                 theForm1.elements['is_js_confirmed'].value = 1;
                 return true;
             }
-            // "DROP/DELETE/ALTER" statement is rejected -> do not submit
-            // the form
+            // statement is rejected -> do not submit the form
             else {
                 window.focus();
                 sqlQuery1.focus();
@@ -279,7 +281,333 @@ function checkSqlQuery(theForm)
     return true;
 } // end of the 'checkSqlQuery()' function
 
+// Global variable row_class is set to even
+var row_class = 'even';
 
+/** 
+* Generates a row dynamically in the differences table displaying
+* the complete statistics of difference in  table like number of 
+* rows to be updated, number of rows to be inserted, number of 
+* columns to be added, number of columns to be removed, etc.
+*
+* @param  index         index of matching table
+* @param  update_size   number of rows/column to be updated
+* @param  insert_size   number of rows/coulmns to be inserted
+* @param  remove_size   number of columns to be removed
+* @param  insert_index  number of indexes to be inserted
+* @param  remove_index  number of indexes to be removed
+* @param  img_obj       image object 
+* @param  table_name    name of the table
+*/
+
+function showDetails(i, update_size, insert_size, remove_size, insert_index, remove_index, img_obj, table_name)
+{   
+    // The path of the image is split to facilitate comparison
+    var relative_path = (img_obj.src).split("themes/"); 
+    
+    // The image source is changed when the showDetails function is called.
+    if (relative_path[1] == 'original/img/new_data_hovered.jpg') {    
+        img_obj.src = "./themes/original/img/new_data_selected_hovered.jpg";
+        img_obj.alt = PMA_messages['strClickToUnselect'];  //only for IE browser
+    } else if (relative_path[1] == 'original/img/new_struct_hovered.jpg') {
+        img_obj.src = "./themes/original/img/new_struct_selected_hovered.jpg";
+        img_obj.alt = PMA_messages['strClickToUnselect'];
+    } else if (relative_path[1] == 'original/img/new_struct_selected_hovered.jpg') {
+        img_obj.src = "./themes/original/img/new_struct_hovered.jpg";
+        img_obj.alt = PMA_messages['strClickToSelect'];
+    } else if (relative_path[1] == 'original/img/new_data_selected_hovered.jpg') {    
+        img_obj.src = "./themes/original/img/new_data_hovered.jpg";
+        img_obj.alt = PMA_messages['strClickToSelect'];
+    } 
+    
+    var div = document.getElementById("list");    
+    var table = div.getElementsByTagName("table")[0]; 
+    var table_body = table.getElementsByTagName("tbody")[0];
+    
+    //Global variable row_class is being used
+    if (row_class == 'even') {
+        row_class = 'odd';
+    } else {
+        row_class = 'even'; 
+    }
+    // If the red or green button against a table name is pressed then append a new row to show the details of differences of this table. 
+    if ((relative_path[1] != 'original/img/new_struct_selected_hovered.jpg') && (relative_path[1] != 'original/img/new_data_selected_hovered.jpg')) { 
+        
+        var newRow = document.createElement("tr");    
+        newRow.setAttribute("class", row_class);
+        newRow.className = row_class; 
+        // Id assigned to this row element is same as the index of this table name in the  matching_tables/source_tables_uncommon array  
+        newRow.setAttribute("id" , i);
+            
+        var table_name_cell = document.createElement("td");
+        table_name_cell.align = "center";
+        table_name_cell.innerHTML = table_name ;
+        
+        newRow.appendChild(table_name_cell);
+       
+        var create_table = document.createElement("td");
+        create_table.align = "center";
+           
+        var add_cols = document.createElement("td");
+        add_cols.align = "center";
+        
+        var remove_cols = document.createElement("td");
+        remove_cols.align = "center";
+        
+        var alter_cols = document.createElement("td");
+        alter_cols.align = "center";
+        
+        var add_index = document.createElement("td");
+        add_index.align = "center";
+        
+        var delete_index = document.createElement("td");
+        delete_index.align = "center";
+        
+        var update_rows = document.createElement("td");
+        update_rows.align = "center";
+        
+        var insert_rows = document.createElement("td");
+        insert_rows.align = "center";
+        
+        var tick_image = document.createElement("img");
+        tick_image.src = "./themes/original/img/s_success.png"; 
+
+        if (update_size == '' && insert_size == '' && remove_size == '') {
+          /**
+          This is the case when the table needs to be created in target database. 
+          */
+            create_table.appendChild(tick_image);
+            add_cols.innerHTML = "--";
+            remove_cols.innerHTML = "--";         
+            alter_cols.innerHTML = "--";
+            delete_index.innerHTML = "--";
+            add_index.innerHTML = "--";
+            update_rows.innerHTML = "--";
+            insert_rows.innerHTML = "--";
+ 
+            newRow.appendChild(create_table);
+            newRow.appendChild(add_cols);
+            newRow.appendChild(remove_cols);
+            newRow.appendChild(alter_cols);
+            newRow.appendChild(delete_index);
+            newRow.appendChild(add_index);
+            newRow.appendChild(update_rows);
+            newRow.appendChild(insert_rows);
+            
+        } else if (update_size == '' && remove_size == '') {
+           /**
+           This is the case when data difference is displayed in the 
+           table which is present in source but absent from target database 
+          */
+            create_table.innerHTML = "--";
+            add_cols.innerHTML = "--";
+            remove_cols.innerHTML = "--";         
+            alter_cols.innerHTML = "--";
+            add_index.innerHTML = "--";
+            delete_index.innerHTML = "--";
+            update_rows.innerHTML = "--";
+            insert_rows.innerHTML = insert_size;
+            
+            newRow.appendChild(create_table);
+            newRow.appendChild(add_cols);
+            newRow.appendChild(remove_cols);
+            newRow.appendChild(alter_cols);
+            newRow.appendChild(delete_index); 
+            newRow.appendChild(add_index);
+            newRow.appendChild(update_rows);
+            newRow.appendChild(insert_rows);
+            
+        } else if (remove_size == '') {
+            /**
+             This is the case when data difference between matching_tables is displayed. 
+            */
+            create_table.innerHTML = "--";
+            add_cols.innerHTML = "--";
+            remove_cols.innerHTML = "--";         
+            alter_cols.innerHTML = "--";
+            add_index.innerHTML = "--";
+            delete_index.innerHTML = "--";
+            update_rows.innerHTML = update_size;
+            insert_rows.innerHTML = insert_size;
+            
+            newRow.appendChild(create_table);
+            newRow.appendChild(add_cols);
+            newRow.appendChild(remove_cols);
+            newRow.appendChild(alter_cols);
+            newRow.appendChild(delete_index);
+            newRow.appendChild(add_index);
+            newRow.appendChild(update_rows);
+            newRow.appendChild(insert_rows);
+            
+        } else {
+            /**
+            This is the case when structure difference between matching_tables id displayed
+            */
+            create_table.innerHTML = "--";
+            add_cols.innerHTML = insert_size;
+            remove_cols.innerHTML = remove_size;         
+            alter_cols.innerHTML = update_size;
+            delete_index.innerHTML = remove_index;
+            add_index.innerHTML = insert_index;
+            update_rows.innerHTML = "--";
+            insert_rows.innerHTML = "--";
+           
+            newRow.appendChild(create_table);
+            newRow.appendChild(add_cols);
+            newRow.appendChild(remove_cols);
+            newRow.appendChild(alter_cols); 
+            newRow.appendChild(delete_index);
+            newRow.appendChild(add_index);
+            newRow.appendChild(update_rows);
+            newRow.appendChild(insert_rows);
+        }
+        table_body.appendChild(newRow);
+      
+    } else if ((relative_path[1] != 'original/img/new_struct_hovered.jpg') && (relative_path[1] != 'original/img/new_data_hovered.jpg')) {
+      //The case when the row showing the details need to be removed from the table i.e. the difference button is deselected now.
+        var table_rows = table_body.getElementsByTagName("tr");
+        var j;
+        var index; 
+        for (j=0; j < table_rows.length; j++) 
+        {   
+            if (table_rows[j].id == i) { 
+                index = j;
+                table_rows[j].parentNode.removeChild(table_rows[j]);     
+            }
+        }
+        //The table row css is being adjusted. Class "odd" for odd rows and "even" for even rows should be maintained.
+        for(index; index < table_rows.length; index++)
+        {
+            row_class_element = table_rows[index].getAttribute('class');
+            if (row_class_element == "even") {
+                table_rows[index].setAttribute("class","odd");  // for Mozilla firefox
+                table_rows[index].className = "odd";            // for IE browser
+            } else {
+                table_rows[index].setAttribute("class","even"); // for Mozilla firefox  
+                table_rows[index].className = "even";           // for IE browser       
+            }
+        }    
+    }     
+}
+
+/**
+ * Changes the image on hover effects
+ *
+ * @param   img_obj   the image object whose source needs to be changed
+ *
+ */
+ 
+function change_Image(img_obj)
+{
+     var relative_path = (img_obj.src).split("themes/"); 
+    
+    if (relative_path[1] == 'original/img/new_data.jpg') {    
+        img_obj.src = "./themes/original/img/new_data_hovered.jpg";  
+    } else if (relative_path[1] == 'original/img/new_struct.jpg') {
+        img_obj.src = "./themes/original/img/new_struct_hovered.jpg";
+    } else if (relative_path[1] == 'original/img/new_struct_hovered.jpg') {
+        img_obj.src = "./themes/original/img/new_struct.jpg";
+    } else if (relative_path[1] == 'original/img/new_data_hovered.jpg') {    
+        img_obj.src = "./themes/original/img/new_data.jpg";  
+    } else if (relative_path[1] == 'original/img/new_data_selected.jpg') {    
+        img_obj.src = "./themes/original/img/new_data_selected_hovered.jpg";  
+    } else if(relative_path[1] == 'original/img/new_struct_selected.jpg') {    
+        img_obj.src = "./themes/original/img/new_struct_selected_hovered.jpg";  
+    } else if (relative_path[1] == 'original/img/new_struct_selected_hovered.jpg') {    
+        img_obj.src = "./themes/original/img/new_struct_selected.jpg";  
+    } else if (relative_path[1] == 'original/img/new_data_selected_hovered.jpg') {    
+        img_obj.src = "./themes/original/img/new_data_selected.jpg";  
+    }
+}
+
+/**
+ * Generates the URL containing the list of selected table ids for synchronization and 
+ * a variable checked for confirmation of deleting previous rows from target tables 
+ *
+ * @param   token   the token generated for each PMA form 
+ *
+ */
+
+function ApplySelectedChanges(token)
+{
+    var div =  document.getElementById("list");
+    var table = div.getElementsByTagName('table')[0];
+    var table_body = table.getElementsByTagName('tbody')[0];
+    // Get all the rows from the details table
+    var table_rows = table_body.getElementsByTagName('tr');
+    var x = table_rows.length;
+    var i;
+    /**
+     Append the token at the beginning of the query string followed by  
+    Table_ids that shows that "Apply Selected Changes" button is pressed            
+    */
+    var append_string = "?token="+token+"&Table_ids="+1;
+    for(i=0; i<x; i++){
+           append_string += "&";    
+           append_string += i+"="+table_rows[i].id; 
+    }
+    
+    // Getting the value of checkbox delete_rows
+    var checkbox = document.getElementById("delete_rows");
+    if (checkbox.checked){
+        append_string += "&checked=true";
+    } else {
+         append_string += "&checked=false";
+    }
+    //Appending the token and list of table ids in the URL 
+    location.href += token;
+    location.href += append_string;
+}
+
+/** 
+* Displays error message if any text field 
+* is left empty other than port field.
+*
+* @param  string   the form name
+* @param  object   the form
+*
+* @return  boolean  whether the form field is empty or not
+*/
+function validateConnection(form_name, form_obj)
+{   
+    var check = true;
+    var src_hostfilled = true;
+    var trg_hostfilled = true;
+
+    for (var i=1; i<form_name.elements.length; i++)
+    {
+        // All the text fields are checked excluding the port field because the default port can be used.
+        if ((form_name.elements[i].type == 'text') && (form_name.elements[i].name != 'src_port') && (form_name.elements[i].name != 'trg_port')) {
+	    check = true;
+            check = emptyFormElements(form_obj, form_name.elements[i].name);
+
+	    if (check==false) {
+	      element = form_name.elements[i].name;
+	      if (form_name.elements[i].name == 'src_host') {
+		src_hostfilled = false;
+		continue;
+	      }
+	      if (form_name.elements[i].name == 'trg_host') {
+		trg_hostfilled = false;
+		continue;
+	      }
+	      if ((form_name.elements[i].name == 'src_socket' && src_hostfilled==false) || (form_name.elements[i].name == 'trg_socket' && trg_hostfilled==false))
+		break;
+	      else
+		continue;
+	      break;
+	    }
+	} 
+    }
+    if (!check) {
+        form_obj.reset();
+        element.select();
+        alert(PMA_messages['strFormEmpty']);
+        element.focus();
+    }
+    return check;
+}
+    
 /**
  * Check if a form's element is empty
  * should be
@@ -308,8 +636,6 @@ function emptyCheckTheField(theForm, theFieldName)
 
 
 /**
- * Displays an error message if an element of a form hasn't been completed and
- * should be
  *
  * @param   object   the form
  * @param   string   the name of the form field to put the focus on
@@ -321,15 +647,8 @@ function emptyFormElements(theForm, theFieldName)
     var theField = theForm.elements[theFieldName];
     var isEmpty = emptyCheckTheField(theForm, theFieldName);
 
-    if (isEmpty) {
-        theForm.reset();
-        theField.select();
-        alert(PMA_messages['strFormEmpty']);
-        theField.focus();
-        return false;
-    }
 
-    return true;
+    return isEmpty;
 } // end of the 'emptyFormElements()' function
 
 
@@ -519,10 +838,14 @@ function PMA_markRowsInit() {
             continue;
         }
         // ... and to mark the row on click ...
-        rows[i].onmousedown = function() {
+        rows[i].onmousedown = function(event) {
             var unique_id;
             var checkbox;
+            var table;
 
+            // Somehow IE8 has this not set
+            if (!event) var event = window.event
+			
             checkbox = this.getElementsByTagName( 'input' )[0];
             if ( checkbox && checkbox.type == 'checkbox' ) {
                 unique_id = checkbox.name + checkbox.value;
@@ -546,6 +869,36 @@ function PMA_markRowsInit() {
 
             if ( checkbox && checkbox.disabled == false ) {
                 checkbox.checked = marked_row[unique_id];
+                if (typeof(event) == 'object') {
+                    table = this.parentNode;
+                    i = 0;
+                    while (table.tagName.toLowerCase() != 'table' && i < 20) {
+                        i++;
+                        table = table.parentNode;
+                    }
+
+                    if (event.shiftKey == true && table.lastClicked != undefined) {
+                        if (event.preventDefault) { event.preventDefault(); } else { event.returnValue = false; }
+                        i = table.lastClicked;
+
+                        if (i < this.rowIndex) {
+                            i++;
+                        } else {
+                            i--;
+                        }
+
+                        while (i != this.rowIndex) {
+                            table.rows[i].onmousedown();
+                            if (i < this.rowIndex) {
+                                i++;
+                            } else {
+                                i--;
+                            }
+                        }
+                    }
+
+                    table.lastClicked = this.rowIndex;
+                }
             }
         }
 
@@ -1032,6 +1385,7 @@ function refreshDragOption(e) {
     myid = getElement(e);
     if (myid.style.visibility == 'visible') {
         refreshLayout();
+        TableDragInit();
     }
 }
 
