@@ -1,43 +1,84 @@
 <?php
-/* $Id: Theme.class.php 9902 2007-02-01 13:25:54Z cybot_tm $ */
-// vim: expandtab sw=4 ts=4 sts=4:
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ * hold PMA_Theme class
+ *
+ * @version $Id$
+ * @package phpMyAdmin
+ */
 
+/**
+ * handles theme
+ *
+ * @todo add the possibility to make a theme depend on another theme and by default on original
+ * @todo make all components optional - get missing components from 'parent' theme
+ * @todo make css optionally replacing 'parent' css or extending it (by appending at the end)
+ * @todo add an optional global css file - which will be used for both frames
+ *
+ * @package phpMyAdmin
+ */
 class PMA_Theme {
     /**
-     * @var string version
+     * @var string theme version
+     * @access  protected
      */
     var $version = '0.0.0.0';
 
     /**
-     * @var string name
+     * @var string theme name
+     * @access  protected
      */
     var $name = '';
 
     /**
-     * @var string id
+     * @var string theme id
+     * @access  protected
      */
     var $id = '';
 
     /**
-     * @var string
+     * @var string theme path
+     * @access  protected
      */
     var $path = '';
 
     /**
-     * @var string
+     * @var string image path
+     * @access  protected
      */
     var $img_path = '';
 
     /**
      * @var array   valid css types
+     * @access  protected
      */
     var $types = array('left', 'right', 'print');
 
     /**
      * @var integer last modification time for info file
+     * @access  protected
      */
     var $mtime_info = 0;
 
+    /**
+     * needed because sometimes, the mtime for different themes
+     * is identical
+     * @var integer filesize for info file
+     * @access  protected
+     */
+    var $filesize_info = 0;
+
+    /**
+     * @access  public
+     * @uses    PMA_Theme::getPath()
+     * @uses    PMA_Theme::$mtime_info
+     * @uses    PMA_Theme::setVersion()
+     * @uses    PMA_Theme::setName()
+     * @uses    filemtime()
+     * @uses    filesize()
+     * @uses    file_exists()
+     * @return  boolean     whether loading them info was successful or not
+     */
     function loadInfo()
     {
         if (! file_exists($this->getPath() . '/info.inc.php')) {
@@ -50,12 +91,13 @@ class PMA_Theme {
 
         @include $this->getPath() . '/info.inc.php';
 
-        // did it set correctly?
+        // was it set correctly?
         if (! isset($theme_name)) {
             return false;
         }
 
         $this->mtime_info = filemtime($this->getPath() . '/info.inc.php');
+        $this->filesize_info = filesize($this->getPath() . '/info.inc.php');
 
         if (isset($theme_full_version)) {
             $this->setVersion($theme_full_version);
@@ -72,12 +114,16 @@ class PMA_Theme {
      * or false if theme is invalid
      *
      * @static
-     * @param   string  path to theme
+     * @access  public
+     * @uses    PMA_Theme
+     * @uses    PMA_Theme::setPath()
+     * @uses    PMA_Theme::loadInfo()
+     * @uses    PMA_Theme::checkImgPath()
+     * @param   string  $folder path to theme
      * @return  object  PMA_Theme
      */
-    function load($folder)
+    static public function load($folder)
     {
-
         $theme = new PMA_Theme();
 
         $theme->setPath($folder);
@@ -91,6 +137,18 @@ class PMA_Theme {
         return $theme;
     }
 
+    /**
+     * checks image path for existance - if not found use img from original theme
+     *
+     * @access  public
+     * @uses    PMA_Theme::getPath()
+     * @uses    PMA_Theme::setImgPath()
+     * @uses    PMA_Theme::getName()
+     * @uses    $GLOBALS['cfg']['ThemePath']
+     * @uses    $GLOBALS['strThemeNoValidImgPath']
+     * @uses    is_dir()
+     * @uses    sprintf()
+     */
     function checkImgPath()
     {
         if (is_dir($this->getPath() . '/img/')) {
@@ -100,18 +158,18 @@ class PMA_Theme {
             $this->setImgPath($GLOBALS['cfg']['ThemePath'] . '/original/img/');
             return true;
         } else {
-            $GLOBALS['PMA_errors'][] =
-                sprintf($GLOBALS['strThemeNoValidImgPath'], $this->getName());
             trigger_error(
                 sprintf($GLOBALS['strThemeNoValidImgPath'], $this->getName()),
-                E_USER_WARNING);
+                E_USER_ERROR);
             return false;
         }
     }
 
     /**
      * returns path to theme
-     * @uses    $this->$path    as return value
+     *
+     * @access  public
+     * @uses    PMA_Theme::$path    as return value
      * @return  string  $path   path to theme
      */
     function getPath()
@@ -122,6 +180,8 @@ class PMA_Theme {
     /**
      * returns layout file
      *
+     * @access  public
+     * @uses    PMA_Theme::getPath()
      * @return  string  layout file
      */
     function getLayoutFile()
@@ -131,7 +191,9 @@ class PMA_Theme {
 
     /**
      * set path to theme
-     * @uses    $this->$path    to set it
+     *
+     * @access  public
+     * @uses    PMA_Theme::$path    to set it
      * @param   string  $path   path to theme
      */
     function setPath($path)
@@ -141,7 +203,9 @@ class PMA_Theme {
 
     /**
      * sets version
-     * @uses    $this->version
+     *
+     * @access  public
+     * @uses    PMA_Theme::$version
      * @param   string new version
      */
     function setVersion($version)
@@ -151,7 +215,9 @@ class PMA_Theme {
 
     /**
      * returns version
-     * @uses    $this->version
+     *
+     * @access  public
+     * @uses    PMA_Theme::$version
      * @return  string  version
      */
     function getVersion()
@@ -163,8 +229,9 @@ class PMA_Theme {
      * checks theme version agaisnt $version
      * returns true if theme version is equal or higher to $version
      *
+     * @access  public
      * @uses    version_compare()
-     * @uses    $this->getVersion()
+     * @uses    PMA_Theme::getVersion()
      * @param   string  $version    version to compare to
      * @return  boolean
      */
@@ -175,6 +242,10 @@ class PMA_Theme {
 
     /**
      * sets name
+     *
+     * @access  public
+     * @uses    PMA_Theme::$name to set it
+     * @uses    trim()
      * @param   string  $name   new name
      */
     function setName($name)
@@ -184,6 +255,9 @@ class PMA_Theme {
 
     /**
      * returns name
+     *
+     * @access  public
+     * @uses    PMA_Theme::$name    as return value
      * @return  string name
      */
     function getName()
@@ -193,6 +267,9 @@ class PMA_Theme {
 
     /**
      * sets id
+     *
+     * @access  public
+     * @uses    PMA_Theme::$id to set it
      * @param   string  $id   new id
      */
     function setId($id)
@@ -202,28 +279,42 @@ class PMA_Theme {
 
     /**
      * returns id
-     * @return  string id
+     *
+     * @access  public
+     * @uses    PMA_Theme::$id as return value
+     * @return  string  id
      */
     function getId()
     {
         return $this->id;
     }
 
+    /**
+     * @access  public
+     * @uses    PMA_Theme::$img_path to set it
+     * @param   string  path to images for this theme
+     */
     function setImgPath($path)
     {
         $this->img_path = $path;
     }
 
+    /**
+     * @access  public
+     * @uses    PMA_Theme::$img_path as retunr value
+     * @return  string image path for this theme
+     */
     function getImgPath()
     {
         return $this->img_path;
     }
 
     /**
-     * load css (send to stdout, normaly the browser)
+     * load css (send to stdout, normally the browser)
      *
-     * @uses    $this->getPath()
-     * @uses    $this->types
+     * @access  public
+     * @uses    PMA_Theme::getPath()
+     * @uses    PMA_Theme::$types
      * @uses    PMA_SQP_buildCssData()
      * @uses    file_exists()
      * @uses    in_array()
@@ -261,10 +352,11 @@ class PMA_Theme {
     /**
      * prints out the preview for this theme
      *
-     * @uses    $this->getName()
-     * @uses    $this->getVersion()
-     * @uses    $this->getId()
-     * @uses    $this->getPath()
+     * @access  public
+     * @uses    PMA_Theme::getName()
+     * @uses    PMA_Theme::getVersion()
+     * @uses    PMA_Theme::getId()
+     * @uses    PMA_Theme::getPath()
      * @uses    $GLOBALS['strThemeNoPreviewAvailable']
      * @uses    $GLOBALS['strTakeIt']
      * @uses    PMA_generate_common_url()
@@ -297,5 +389,4 @@ class PMA_Theme {
             .'</div>';
     }
 }
-
-?>
\ No newline at end of file
+?>
