@@ -1,40 +1,34 @@
 <?php
-/* $Id: mysqli.dbi.lib.php 9662 2006-11-02 13:34:14Z nijel $ */
-// vim: expandtab sw=4 ts=4 sts=4:
-
+/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Interface to the improved MySQL extension (MySQLi)
+ *
+ * @package phpMyAdmin-DBI-MySQLi
+ * @version $Id$
  */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
-// MySQL client API
+require_once './libraries/logging.lib.php';
+
+/**
+ * MySQL client API
+ */
 if (!defined('PMA_MYSQL_CLIENT_API')) {
     $client_api = explode('.', mysqli_get_client_info());
     define('PMA_MYSQL_CLIENT_API', (int)sprintf('%d%02d%02d', $client_api[0], $client_api[1], intval($client_api[2])));
     unset($client_api);
 }
 
-// Constants from mysql_com.h of MySQL 4.1.3
 /**
- * @deprecated
-define('NOT_NULL_FLAG',         MYSQLI_NOT_NULL_FLAG);
-define('PRI_KEY_FLAG',          MYSQLI_PRI_KEY_FLAG);
-define('UNIQUE_KEY_FLAG',       MYSQLI_UNIQUE_KEY_FLAG);
-define('MULTIPLE_KEY_FLAG',     MYSQLI_MULTIPLE_KEY_FLAG);
-define('BLOB_FLAG',             MYSQLI_BLOB_FLAG);
-define('UNSIGNED_FLAG',         MYSQLI_UNSIGNED_FLAG);
-define('ZEROFILL_FLAG',         MYSQLI_ZEROFILL_FLAG);
-define('BINARY_FLAG',           MYSQLI_BINARY_FLAG);
-define('ENUM_FLAG',             MYSQLI_TYPE_ENUM);
-define('AUTO_INCREMENT_FLAG',   MYSQLI_AUTO_INCREMENT_FLAG);
-define('TIMESTAMP_FLAG',        MYSQLI_TIMESTAMP_FLAG);
-define('SET_FLAG',              MYSQLI_SET_FLAG);
-define('NUM_FLAG',              MYSQLI_NUM_FLAG);
-define('PART_KEY_FLAG',         MYSQLI_PART_KEY_FLAG);
-define('UNIQUE_FLAG',           MYSQLI_UNIQUE_FLAG);
+ * some PHP versions are reporting extra messages like "No index used in query"
  */
 
+mysqli_report(MYSQLI_REPORT_OFF);
+
 /**
- * some older mysql client libs are missing this constants ...
+ * some older mysql client libs are missing these constants ...
  */
 if (! defined('MYSQLI_BINARY_FLAG')) {
    define('MYSQLI_BINARY_FLAG', 128);
@@ -66,22 +60,37 @@ if (! defined('MYSQLI_TYPE_BIT')) {
  * @param   string  $user           mysql user name
  * @param   string  $password       mysql user password
  * @param   boolean $is_controluser
+ * @param   array   $server host/port/socket 
+ * @param   boolean $auxiliary_connection (when true, don't go back to login if connection fails)
  * @return  mixed   false on error or a mysqli object on success
  */
-function PMA_DBI_connect($user, $password, $is_controluser = false)
+function PMA_DBI_connect($user, $password, $is_controluser = false, $server = null, $auxiliary_connection = false)
 {
-    $server_port   = (empty($GLOBALS['cfg']['Server']['port']))
-                   ? false
-                   : (int) $GLOBALS['cfg']['Server']['port'];
+    if ($server) {
+          $server_port   = (empty($server['port']))
+                   ? ''
+                   : (int)$server['port'];
+	  $server_socket = (empty($server['socket']))
+                   ? ''
+                   : $server['socket'];
+	  $server['host'] = (empty($server['host']))
+		   ? 'localhost'
+		   : $server['host'];
+    } else {
+	  $server_port   = (empty($GLOBALS['cfg']['Server']['port']))
+			 ? false
+			 : (int) $GLOBALS['cfg']['Server']['port'];
+	  $server_socket = (empty($GLOBALS['cfg']['Server']['socket']))
+			 ? null
+			 : $GLOBALS['cfg']['Server']['socket'];
+    }
+
 
     if (strtolower($GLOBALS['cfg']['Server']['connect_type']) == 'tcp') {
         $GLOBALS['cfg']['Server']['socket'] = '';
     }
 
     // NULL enables connection to the default socket
-    $server_socket = (empty($GLOBALS['cfg']['Server']['socket']))
-                   ? null
-                   : $GLOBALS['cfg']['Server']['socket'];
 
     $link = mysqli_init();
 
@@ -98,19 +107,34 @@ function PMA_DBI_connect($user, $password, $is_controluser = false)
     if ($GLOBALS['cfg']['Server']['ssl'] && defined('MYSQLI_CLIENT_SSL')) {
         $client_flags |= MYSQLI_CLIENT_SSL;
     }
-
-    $return_value = @mysqli_real_connect($link, $GLOBALS['cfg']['Server']['host'], $user, $password, false, $server_port, $server_socket, $client_flags);
-
-    // Retry with empty password if we're allowed to
-    if ($return_value == false && isset($cfg['Server']['nopassword']) && $cfg['Server']['nopassword'] && !$is_controluser) {
-        $return_value = @mysqli_real_connect($link, $GLOBALS['cfg']['Server']['host'], $user, '', false, $server_port, $server_socket, $client_flags);
+    
+    if (!$server) {
+      $return_value = @mysqli_real_connect($link, $GLOBALS['cfg']['Server']['host'], $user, $password, false, $server_port, $server_socket, $client_flags);
+      // Retry with empty password if we're allowed to
+      if ($return_value == false && isset($GLOBALS['cfg']['Server']['nopassword']) && $GLOBALS['cfg']['Server']['nopassword'] && !$is_controluser) {
+	  $return_value = @mysqli_real_connect($link, $GLOBALS['cfg']['Server']['host'], $user, '', false, $server_port, $server_socket, $client_flags);
+      }
+    } else {
+      $return_value = @mysqli_real_connect($link, $server['host'], $user, $password, false, $server_port, $server_socket);
     }
 
     if ($return_value == false) {
-        PMA_auth_fails();
-    } // end if
-
-    PMA_DBI_postConnect($link, $is_controluser);
+	    if ($is_controluser) {
+	        trigger_error($GLOBALS['strControluserFailed'], E_USER_WARNING);
+	        return false;
+	    }
+        // we could be calling PMA_DBI_connect() to connect to another
+        // server, for example in the Synchronize feature, so do not
+        // go back to main login if it fails 
+        if (! $auxiliary_connection) {
+	        PMA_log_user($user, 'mysql-denied');
+            PMA_auth_fails();
+        } else {
+            return false;
+        }
+    } else {
+        PMA_DBI_postConnect($link, $is_controluser);
+    }
 
     return $link;
 }
@@ -119,12 +143,11 @@ function PMA_DBI_connect($user, $password, $is_controluser = false)
  * selects given database
  *
  * @uses    $GLOBALS['userlink']
- * @uses    PMA_MYSQL_INT_VERSION
  * @uses    PMA_convert_charset()
  * @uses    mysqli_select_db()
  * @param   string          $dbname database name to select
- * @param   object mysqli   $link   the mysli object
- * @return  boolean         treu or false
+ * @param   object mysqli   $link   the mysqli object
+ * @return  boolean         true or false
  */
 function PMA_DBI_select_db($dbname, $link = null)
 {
@@ -135,9 +158,6 @@ function PMA_DBI_select_db($dbname, $link = null)
             return false;
         }
     }
-    if (PMA_MYSQL_INT_VERSION < 40100) {
-        $dbname = PMA_convert_charset($dbname);
-    }
     return mysqli_select_db($link, $dbname);
 }
 
@@ -146,7 +166,6 @@ function PMA_DBI_select_db($dbname, $link = null)
  *
  * @uses    PMA_DBI_QUERY_STORE
  * @uses    PMA_DBI_QUERY_UNBUFFERED
- * @uses    PMA_MYSQL_INT_VERSION
  * @uses    $GLOBALS['userlink']
  * @uses    PMA_convert_charset()
  * @uses    MYSQLI_STORE_RESULT
@@ -175,25 +194,46 @@ function PMA_DBI_try_query($query, $link = null, $options = 0)
             return false;
         }
     }
-    if (defined('PMA_MYSQL_INT_VERSION') && PMA_MYSQL_INT_VERSION < 40100) {
-        $query = PMA_convert_charset($query);
-    }
-    $result = mysqli_query($link, $query, $method);
 
-    if (mysqli_warning_count($link)) {
-        /**
-         * @todo check $method ?
-         */
-        $warning_result = mysqli_query($link, 'SHOW WARNINGS');
-        if ($warning_result) {
-            $warning_row = mysqli_fetch_row($warning_result);
-            $GLOBALS['warning'] = sprintf("%s (%d): %s", $warning_row[0], $warning_row[1], $warning_row[2]);
+    if ($GLOBALS['cfg']['DBG']['sql']) {
+        $time = microtime(true);
+    }
+    $r = mysqli_query($link, $query, $method);
+    if ($GLOBALS['cfg']['DBG']['sql']) {
+        $time = microtime(true) - $time;
+
+        $hash = md5($query);
+
+        if (isset($_SESSION['debug']['queries'][$hash])) {
+            $_SESSION['debug']['queries'][$hash]['count']++;
+        } else {
+            $_SESSION['debug']['queries'][$hash] = array();
+            $_SESSION['debug']['queries'][$hash]['count'] = 1;
+            $_SESSION['debug']['queries'][$hash]['query'] = $query;
+            $_SESSION['debug']['queries'][$hash]['time'] = $time;
         }
-    } else {
-        unset($GLOBALS['warning']);
+
+        $trace = array();
+        foreach (debug_backtrace() as $trace_step) {
+            $trace[] = PMA_Error::relPath($trace_step['file']) . '#'
+                . $trace_step['line'] . ': '
+                . (isset($trace_step['class']) ? $trace_step['class'] : '')
+                //. (isset($trace_step['object']) ? get_class($trace_step['object']) : '')
+                . (isset($trace_step['type']) ? $trace_step['type'] : '')
+                . (isset($trace_step['function']) ? $trace_step['function'] : '')
+                . '('
+                . (isset($trace_step['params']) ? implode(', ', $trace_step['params']) : '')
+                . ')'
+                ;
+        }
+        $_SESSION['debug']['queries'][$hash]['trace'][] = $trace;
     }
 
-    return $result;
+    if ($r != FALSE && PMA_Tracker::isActive() == TRUE ) {
+        PMA_Tracker::handleQuery($query); 
+    }
+
+    return $r;
 
     // From the PHP manual:
     // "note: returns true on success or false on failure. For SELECT,
@@ -202,131 +242,56 @@ function PMA_DBI_try_query($query, $link = null, $options = 0)
     // a boolean
 }
 
-/**
- * returns $type array of rows from given $result
- *
- * The following function is meant for internal use only.
- * Do not call it from outside this library!
- *
- * @uses    $GLOBALS['allow_recoding']
- * @uses    $GLOBALS['cfg']['AllowAnywhereRecoding']
- * @uses    PMA_MYSQL_INT_VERSION
- * @uses    PMA_DBI_get_fields_meta()
- * @uses    PMA_convert_display_charset()
- * @uses    mysqli_fetch_array()
- * @uses    mysqli_num_fields()
- * @uses    stristr()
- * @param   object mysqli result    $result
- * @param   integer                 $type   ASSOC, BOTH, or NUMERIC array
- * @return  array                   results
- * @access  protected
- */
-function PMA_mysqli_fetch_array($result, $type = false)
-{
-    if ($type != false) {
-        $data = @mysqli_fetch_array($result, $type);
-    } else {
-        $data = @mysqli_fetch_array($result);
-    }
-
-    /* No data returned => do not touch it */
-    if (! $data) {
-        return $data;
-    }
-
-    if (!defined('PMA_MYSQL_INT_VERSION') || PMA_MYSQL_INT_VERSION >= 40100
-      || !(isset($GLOBALS['cfg']['AllowAnywhereRecoding'])
-        && $GLOBALS['cfg']['AllowAnywhereRecoding']
-        && $GLOBALS['allow_recoding'])) {
-        /* No recoding -> return data as we got them */
-        return $data;
-    }
-
-    $ret    = array();
-    $num    = mysqli_num_fields($result);
-    if ($num > 0) {
-        $fields = PMA_DBI_get_fields_meta($result);
-    }
-    // sometimes, mysqli_fetch_fields() does not return results
-    // (as seen in PHP 5.1.0-dev), so for now, return $data unchanged
-    if (!$fields) {
-        return $data;
-    }
-    $i = 0;
-    for ($i = 0; $i < $num; $i++) {
-        if (!isset($fields[$i]->type)) {
-            /* No meta information available -> we guess that it should be
-             * converted */
-            if (isset($data[$i])) {
-                $ret[$i] = PMA_convert_display_charset($data[$i]);
-            }
-            if (isset($fields[$i]->name) && isset($data[$fields[$i]->name])) {
-                $ret[PMA_convert_display_charset($fields[$i]->name)] =
-                    PMA_convert_display_charset($data[$fields[$i]->name]);
-            }
-        } else {
-            /* Meta information available -> check type of field and convert
-             * it according to the type */
-            if (stristr($fields[$i]->type, 'BLOB')
-              || stristr($fields[$i]->type, 'BINARY')) {
-                if (isset($data[$i])) {
-                    $ret[$i] = $data[$i];
-                }
-                if (isset($data[$fields[$i]->name])) {
-                    $ret[PMA_convert_display_charset($fields[$i]->name)] =
-                        $data[$fields[$i]->name];
-                }
-            } else {
-                if (isset($data[$i])) {
-                    $ret[$i] = PMA_convert_display_charset($data[$i]);
-                }
-                if (isset($data[$fields[$i]->name])) {
-                    $ret[PMA_convert_display_charset($fields[$i]->name)] =
-                        PMA_convert_display_charset($data[$fields[$i]->name]);
-                }
-            }
-        }
-    }
-    return $ret;
-}
-
 /**
  * returns array of rows with associative and numeric keys from $result
  *
- * @uses    PMA_mysqli_fetch_array()
+ * @uses    mysqli_fetch_array()
  * @uses    MYSQLI_BOTH
  * @param   object mysqli result    $result
  * @return  array                   result rows
  */
 function PMA_DBI_fetch_array($result)
 {
-    return PMA_mysqli_fetch_array($result, MYSQLI_BOTH);
+    return mysqli_fetch_array($result, MYSQLI_BOTH);
 }
 
 /**
  * returns array of rows with associative keys from $result
  *
- * @uses    PMA_mysqli_fetch_array()
+ * @uses    mysqli_fetch_array()
  * @uses    MYSQLI_ASSOC
  * @param   object mysqli result    $result
  * @return  array                   result rows
  */
 function PMA_DBI_fetch_assoc($result)
 {
-    return PMA_mysqli_fetch_array($result, MYSQLI_ASSOC);
+    return mysqli_fetch_array($result, MYSQLI_ASSOC);
 }
 
 /**
  * returns array of rows with numeric keys from $result
  *
- * @uses    PMA_mysqli_fetch_array()
+ * @uses    mysqli_fetch_array()
  * @uses    MYSQLI_NUM
  * @param   object mysqli result    $result
  * @return  array                   result rows
  */
 function PMA_DBI_fetch_row($result)
 {
-    return PMA_mysqli_fetch_array($result, MYSQLI_NUM);
+    return mysqli_fetch_array($result, MYSQLI_NUM);
+}
+
+/*
+ * Adjusts the result pointer to an arbitrary row in the result
+ *
+ * @uses    mysqli_data_seek()
+ * @param   $result
+ * @param   $offset
+ * @return  boolean true on success, false on failure
+ */
+function PMA_DBI_data_seek($result, $offset)
+{
+    return mysqli_data_seek($result, $offset);
 }
 
 /**
@@ -334,16 +299,13 @@ function PMA_DBI_fetch_row($result)
  *
  * @uses    mysqli_result
  * @uses    func_get_args()
- * @uses    is_object()
- * @uses    is_a()
  * @uses    mysqli_free_result()
  * @param   result  $result,...     one or more mysql result resources
  */
 function PMA_DBI_free_result()
 {
     foreach (func_get_args() as $result) {
-        if (is_object($result)
-          && is_a($result, 'mysqli_result')) {
+        if ($result instanceof mysqli_result) {
             mysqli_free_result($result);
         }
     }
@@ -375,7 +337,7 @@ function PMA_DBI_get_host_info($link = null)
  * @param   resource        $link   mysql link
  * @return  integer         version of the MySQL protocol used
  */
-function PMA_DBI_get_proto_info( $link = null )
+function PMA_DBI_get_proto_info($link = null)
 {
     if (null === $link) {
         if (isset($GLOBALS['userlink'])) {
@@ -400,8 +362,6 @@ function PMA_DBI_get_client_info()
 /**
  * returns last error message or false if no errors occured
  *
- * @uses    PMA_MYSQL_INT_VERSION
- * @uses    PMA_convert_display_charset()
  * @uses    PMA_DBI_convert_message()
  * @uses    $GLOBALS['errno']
  * @uses    $GLOBALS['userlink']
@@ -419,6 +379,11 @@ function PMA_DBI_getError($link = null)
 {
     $GLOBALS['errno'] = 0;
 
+    /* Treat false same as null because of controllink */
+    if ($link === false) {
+        $link = null;
+    }
+
     if (null === $link && isset($GLOBALS['userlink'])) {
         $link =& $GLOBALS['userlink'];
         // Do not stop now. We still can get the error code
@@ -445,36 +410,16 @@ function PMA_DBI_getError($link = null)
         $error_message = PMA_DBI_convert_message($error_message);
     }
 
+    $error_message = htmlspecialchars($error_message);
+
     if ($error_number == 2002) {
         $error = '#' . ((string) $error_number) . ' - ' . $GLOBALS['strServerNotResponding'] . ' ' . $GLOBALS['strSocketProblem'];
-    } elseif (defined('PMA_MYSQL_INT_VERSION') && PMA_MYSQL_INT_VERSION >= 40100) {
-        $error = '#' . ((string) $error_number) . ' - ' . $error_message;
     } else {
-        $error = '#' . ((string) $error_number) . ' - ' . PMA_convert_display_charset($error_message);
+        $error = '#' . ((string) $error_number) . ' - ' . $error_message;
     }
     return $error;
 }
 
-/**
- * closes given database $link or $GLOBALS['userlink']
- *
- * @uses    $GLOBALS['userlink']
- * @uses    mysqli_close()
- * @param   object mysqli   $link   the mysqli object
- * @return  boolean         treu or false
- */
-function PMA_DBI_close($link = null)
-{
-    if (empty($link)) {
-        if (isset($GLOBALS['userlink'])) {
-            $link = $GLOBALS['userlink'];
-        } else {
-            return false;
-        }
-    }
-    return @mysqli_close($link);
-}
-
 /**
  *
  * @param   object mysqli result    $result
@@ -556,7 +501,7 @@ function PMA_DBI_get_fields_meta($result)
     $typeAr = array();
     $typeAr[MYSQLI_TYPE_DECIMAL]     = 'real';
     $typeAr[MYSQLI_TYPE_NEWDECIMAL]  = 'real';
-    $typeAr[MYSQLI_TYPE_BIT]         = 'bool';
+    $typeAr[MYSQLI_TYPE_BIT]         = 'int';
     $typeAr[MYSQLI_TYPE_TINY]        = 'int';
     $typeAr[MYSQLI_TYPE_SHORT]       = 'int';
     $typeAr[MYSQLI_TYPE_LONG]        = 'int';
@@ -584,7 +529,8 @@ function PMA_DBI_get_fields_meta($result)
     // so this would override TINYINT and mark all TINYINT as string
     // https://sf.net/tracker/?func=detail&aid=1532111&group_id=23067&atid=377408
     //$typeAr[MYSQLI_TYPE_CHAR]        = 'string';
-    $typeAr[MYSQLI_TYPE_GEOMETRY]    = 'unknown';
+    $typeAr[MYSQLI_TYPE_GEOMETRY]    = 'geometry';
+    $typeAr[MYSQLI_TYPE_BIT]         = 'bit';
 
     $fields = mysqli_fetch_fields($result);
 
@@ -643,10 +589,7 @@ function PMA_DBI_num_fields($result)
  */
 function PMA_DBI_field_len($result, $i)
 {
-    $info = mysqli_fetch_field_direct($result, $i);
-    // stdClass::$length will be integrated in
-    // mysqli-ext when mysql4.1 has been released.
-    return @$info->length;
+    return mysqli_fetch_field_direct($result, $i)->length;
 }
 
 /**
@@ -659,8 +602,7 @@ function PMA_DBI_field_len($result, $i)
  */
 function PMA_DBI_field_name($result, $i)
 {
-    $info = mysqli_fetch_field_direct($result, $i);
-    return $info->name;
+    return mysqli_fetch_field_direct($result, $i)->name;
 }
 
 /**
@@ -673,7 +615,6 @@ function PMA_DBI_field_name($result, $i)
  * @uses    MYSQLI_TIMESTAMP_FLAG
  * @uses    MYSQLI_AUTO_INCREMENT_FLAG
  * @uses    MYSQLI_TYPE_ENUM
- * @uses    MYSQLI_BINARY_FLAG
  * @uses    MYSQLI_ZEROFILL_FLAG
  * @uses    MYSQLI_UNSIGNED_FLAG
  * @uses    MYSQLI_BLOB_FLAG
@@ -681,26 +622,41 @@ function PMA_DBI_field_name($result, $i)
  * @uses    MYSQLI_UNIQUE_KEY_FLAG
  * @uses    MYSQLI_PRI_KEY_FLAG
  * @uses    MYSQLI_NOT_NULL_FLAG
+ * @uses    MYSQLI_TYPE_BLOB
+ * @uses    MYSQLI_TYPE_MEDIUM_BLOB
+ * @uses    MYSQLI_TYPE_LONG_BLOB
+ * @uses    MYSQLI_TYPE_VAR_STRING
+ * @uses    MYSQLI_TYPE_STRING
  * @uses    mysqli_fetch_field_direct()
- * @uses    PMA_convert_display_charset()
  * @param   object mysqli result    $result
  * @param   integer                 $i      field
  * @return  string                  field flags
  */
 function PMA_DBI_field_flags($result, $i)
 {
+    // This is missing from PHP 5.2.5, see http://bugs.php.net/bug.php?id=44846
+    if (! defined('MYSQLI_ENUM_FLAG')) {
+        define('MYSQLI_ENUM_FLAG', 256); // see MySQL source include/mysql_com.h
+    }
     $f = mysqli_fetch_field_direct($result, $i);
+    $type = $f->type;
+    $charsetnr = $f->charsetnr;
     $f = $f->flags;
     $flags = '';
     if ($f & MYSQLI_UNIQUE_KEY_FLAG)     { $flags .= 'unique ';}
     if ($f & MYSQLI_NUM_FLAG)            { $flags .= 'num ';}
     if ($f & MYSQLI_PART_KEY_FLAG)       { $flags .= 'part_key ';}
-    if ($f & MYSQLI_TYPE_SET)            { $flags .= 'set ';}
+    if ($f & MYSQLI_SET_FLAG)            { $flags .= 'set ';}
     if ($f & MYSQLI_TIMESTAMP_FLAG)      { $flags .= 'timestamp ';}
     if ($f & MYSQLI_AUTO_INCREMENT_FLAG) { $flags .= 'auto_increment ';}
-    if ($f & MYSQLI_TYPE_ENUM)           { $flags .= 'enum ';}
-    // @TODO seems to be outdated
-    if ($f & MYSQLI_BINARY_FLAG)         { $flags .= 'binary ';}
+    if ($f & MYSQLI_ENUM_FLAG)           { $flags .= 'enum ';}
+    // See http://dev.mysql.com/doc/refman/6.0/en/c-api-datatypes.html:
+    // to determine if a string is binary, we should not use MYSQLI_BINARY_FLAG
+    // but instead the charsetnr member of the MYSQL_FIELD
+    // structure. Watch out: some types like DATE returns 63 in charsetnr
+    // so we have to check also the type.
+    // Unfortunately there is no equivalent in the mysql extension.
+    if (($type == MYSQLI_TYPE_TINY_BLOB || $type == MYSQLI_TYPE_BLOB || $type == MYSQLI_TYPE_MEDIUM_BLOB || $type == MYSQLI_TYPE_LONG_BLOB || $type == MYSQLI_TYPE_VAR_STRING || $type == MYSQLI_TYPE_STRING) && 63 == $charsetnr)                { $flags .= 'binary ';}
     if ($f & MYSQLI_ZEROFILL_FLAG)       { $flags .= 'zerofill ';}
     if ($f & MYSQLI_UNSIGNED_FLAG)       { $flags .= 'unsigned ';}
     if ($f & MYSQLI_BLOB_FLAG)           { $flags .= 'blob ';}
@@ -708,7 +664,7 @@ function PMA_DBI_field_flags($result, $i)
     if ($f & MYSQLI_UNIQUE_KEY_FLAG)     { $flags .= 'unique_key ';}
     if ($f & MYSQLI_PRI_KEY_FLAG)        { $flags .= 'primary_key ';}
     if ($f & MYSQLI_NOT_NULL_FLAG)       { $flags .= 'not_null ';}
-    return PMA_convert_display_charset(trim($flags));
+    return trim($flags);
 }
 
 ?>
