@@ -307,9 +307,60 @@ function PMA_exportDBCreate($db)
         return FALSE;
     }
     if (isset($GLOBALS['sql_backquotes']) && isset($GLOBALS['sql_compatibility']) && $GLOBALS['sql_compatibility'] == 'NONE') {
-        return PMA_exportOutputHandler('USE ' . PMA_backquote($db) . ';' . $crlf);
+        $result = PMA_exportOutputHandler('USE ' . PMA_backquote($db) . ';' . $crlf);
+    } else {
+        $result = PMA_exportOutputHandler('USE ' . $db . ';' . $crlf);
     }
-    return PMA_exportOutputHandler('USE ' . $db . ';' . $crlf);
+
+    if ($result && isset($GLOBALS['sql_structure']) && isset($GLOBALS['sql_procedure_function'])) {
+        $text = '';
+        $delimiter = '$$';
+
+        $procedure_names = PMA_DBI_get_procedures_or_functions($db, 'PROCEDURE');
+        $function_names = PMA_DBI_get_procedures_or_functions($db, 'FUNCTION');
+
+        if ($procedure_names || $function_names) {
+            $text .= $crlf
+              . 'DELIMITER ' . $delimiter . $crlf;
+        }
+
+        if ($procedure_names) {
+            $text .=
+                PMA_exportComment()
+              . PMA_exportComment($GLOBALS['strProcedures'])
+              . PMA_exportComment();
+
+            foreach($procedure_names as $procedure_name) {
+                if (! empty($GLOBALS['sql_drop_table'])) {
+		    $text .= 'DROP PROCEDURE IF EXISTS ' . PMA_backquote($procedure_name) . $delimiter . $crlf;
+                }
+                $text .= PMA_DBI_get_definition($db, 'PROCEDURE', $procedure_name) . $delimiter . $crlf . $crlf;
+            }
+        }
+
+        if ($function_names) {
+            $text .=
+                PMA_exportComment()
+              . PMA_exportComment($GLOBALS['strFunctions'])
+              . PMA_exportComment();
+
+            foreach($function_names as $function_name) {
+                if (! empty($GLOBALS['sql_drop_table'])) {
+		    $text .= 'DROP FUNCTION IF EXISTS ' . PMA_backquote($function_name) . $delimiter . $crlf;
+                }
+                $text .= PMA_DBI_get_definition($db, 'FUNCTION', $function_name) . $delimiter . $crlf . $crlf;
+            }
+        }
+
+        if ($procedure_names || $function_names) {
+            $text .= 'DELIMITER ;' . $crlf;
+        }
+
+        if (! empty($text)) {
+            $result = PMA_exportOutputHandler($text);
+        }
+    }
+    return $result;
 }
 
 /**
@@ -352,49 +403,16 @@ function PMA_exportDBFooter($db)
         $text = '';
         $delimiter = '$$';
 
-        $procedure_names = PMA_DBI_get_procedures_or_functions($db, 'PROCEDURE');
-        $function_names = PMA_DBI_get_procedures_or_functions($db, 'FUNCTION');
-
         if (PMA_MYSQL_INT_VERSION > 50100) {
             $event_names = PMA_DBI_fetch_result('SELECT EVENT_NAME FROM information_schema.EVENTS WHERE EVENT_SCHEMA= \'' . PMA_sqlAddslashes($db,true) . '\';');
         } else {
             $event_names = array();
         }
 
-        if ($procedure_names || $function_names || $event_names) {
+        if ($event_names) {
             $text .= $crlf
               . 'DELIMITER ' . $delimiter . $crlf;
-        }
 
-        if ($procedure_names) {
-            $text .=
-                PMA_exportComment()
-              . PMA_exportComment($GLOBALS['strProcedures'])
-              . PMA_exportComment();
-
-            foreach($procedure_names as $procedure_name) {
-                if (! empty($GLOBALS['sql_drop_table'])) {
-		    $text .= 'DROP PROCEDURE IF EXISTS ' . PMA_backquote($procedure_name) . $delimiter . $crlf;
-                }
-                $text .= PMA_DBI_get_definition($db, 'PROCEDURE', $procedure_name) . $delimiter . $crlf . $crlf;
-            }
-        }
-
-        if ($function_names) {
-            $text .=
-                PMA_exportComment()
-              . PMA_exportComment($GLOBALS['strFunctions'])
-              . PMA_exportComment();
-
-            foreach($function_names as $function_name) {
-                if (! empty($GLOBALS['sql_drop_table'])) {
-		    $text .= 'DROP FUNCTION IF EXISTS ' . PMA_backquote($function_name) . $delimiter . $crlf;
-                }
-                $text .= PMA_DBI_get_definition($db, 'FUNCTION', $function_name) . $delimiter . $crlf . $crlf;
-            }
-        }
-
-        if ($event_names) {
             $text .=
                 PMA_exportComment()
               . PMA_exportComment($GLOBALS['strEvents'])
@@ -406,8 +424,7 @@ function PMA_exportDBFooter($db)
                 }
                 $text .= PMA_DBI_get_definition($db, 'EVENT', $event_name) . $delimiter . $crlf . $crlf;
             }
-        }
-        if ($procedure_names || $function_names || $event_names) {
+
             $text .= 'DELIMITER ;' . $crlf;
         }
 
@@ -423,7 +440,7 @@ function PMA_exportDBFooter($db)
  * Returns a stand-in CREATE definition to resolve view dependencies
  *
  * @param   string   the database name
- * @param   string   the vew name
+ * @param   string   the view name
  * @param   string   the end of line sequence
  *
  * @return  string   resulting definition
